@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use Moo;
 use strictures 2;
@@ -34,10 +34,9 @@ has pool => (
 );
 
 has _min_size => (
-    is       => 'ro',
-    builder  => 1,
-    lazy     => 1,
-    init_arg => undef,
+    is      => 'ro',
+    builder => 1,
+    lazy    => 1,
 );
 
 sub _build__min_size {
@@ -48,6 +47,17 @@ sub _build__min_size {
     return min(@sizes);
 }
 
+has _mrd => (
+    is      => 'ro',
+    builder => 1,
+    lazy    => 1,
+);
+
+sub _build__mrd {
+    my ($self) = @_;
+    return Math::Random::Discrete->new($self->weights, $self->pool);
+}
+
 
 has pool_code => (
     is      => 'rw',
@@ -57,8 +67,7 @@ has pool_code => (
 
 sub _build_pool_code {
     my ($self) = @_;
-    my $choice = Math::Random::Discrete->new($self->weights, $self->pool);
-    return sub { return $choice->rand };
+    return sub { return $self->_mrd->rand };
 };
 
 
@@ -71,7 +80,7 @@ has weights => (
 sub _build_weights {
     my ($self) = @_;
     # Equal probability for all pool members
-    return [ map { 1 } @{ $self->pool } ];
+    return [ (1) x @{ $self->pool } ];
 }
 
 
@@ -115,13 +124,16 @@ sub motif {
 
 sub _duration {
     my ( $self, $name ) = @_;
+
     my $dura;
+
     if ($name =~ /^d(\d+)$/) {
         $dura = $1;
     }
     else {
         $dura = $self->durations->{$name};
     }
+
     return $dura;
 }
 
@@ -139,7 +151,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
@@ -211,13 +223,13 @@ mixture of both is not well defined. YMMV
 
 =head2 pool_code
 
-  $name = $mdp->pool_code->();
+  $code = $mdp->pool_code->();
   $mdp->pool_code( sub { ... } );
 
 A code reference used to select an item from the given duration
 B<pool>.
 
-Default: Random item of B<pool>
+Default: Random item from B<pool>
 
 =head2 weights
 
@@ -256,14 +268,16 @@ application, in a loop until the B<size> is met.
 
 =head1 SEE ALSO
 
-The F<t/01-methods.t> and F<eg/*> code in this distribution.
+The F<eg/*> and F<t/01-methods.t> programs in this distribution.
 
 L<List::Util>
 
-L<Moo>
+L<Math::Random::Discrete>
 
 L<MIDI::Simple>
 
+L<Moo>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
